package DB;

use strict;
use warnings;
use DB::Schema;
use DateTime;

use Data::Dumper;

my $schema = DB::Schema->connect("sports");

sub deploy {
  $schema->deploy();
}

sub _get_date {
  my $rs = shift;
  my $date = shift;

  unless ($date) {
    my $column = $schema->resultset("Redzonescoring")->get_column('date');
    my $maxdate = $column->max();
    $date = $maxdate;
  }

  return $date;
}

sub _get_array_ref {
  my $row = shift;
  return [$row->team->team, $row->rank, $row->current_season, $row->last_three, $row->last_one, $row->home, $row->away, $row->last_season];
}

sub _city_to_team {
  my $city = shift;
  $schema->resultset("Team")->search({city => $city})->first()->team_id
}

sub get_data {
  my $zone = shift;
  my $date = _get_date($zone, shift);
  
  my $rs = $schema->resultset("TeamsData")->search({date => $date, zone => $zone}, {join => qw/team/, order_by => { -asc => 'team.team' }});

  my @rows;
  
  while (my $row = $rs->next) {
    push @rows, _get_array_ref($row);
  }
  return @rows;
}

sub insert_data {
  my $zone = shift;
  my $date = shift;
  my $scores = shift;

  my $team_id = _city_to_team($scores->{city});

  delete $scores->{city};

  my $row = {
    team_id => $team_id,
    date => $date,
    zone => $zone,
    %$scores,
  };
  
  my $rows = $schema->resultset("TeamsData")->update_or_create($row);

  return $rows;
}
