package Scrape;

use strict;
use warnings;

use WWW::Mechanize;
use HTML::TableExtract;
use HTML::TreeBuilder;
use DateTime;

use Data::Dumper;
use List::MoreUtils qw/zip/;

my $mech = WWW::Mechanize->new(agent=>"Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
  my $referer = "http://www.teamrankings.com/nfl/stat/red-zone-scoring-pct?date=".(DateTime->now()->ymd);

  $mech->get($referer);
  $mech->add_header(
    Referer => $referer,
    Accept => '*/*',
    "Accept-Language" => 'en,en-us;q=0.5',
    "Accept-Charset"  => 'UTF-8,*',
    DNT => 1,
    "X-Requested-With" => "XMLHttpRequest",
  );

my $baseurl = "http://www.teamrankings.com/ajax/league/v3/stats_controller.php";

my %basevars = (
);

sub _parse_table {
  my $headers = shift;
  my $fields = shift;
  my $table = shift;

  my $te = HTML::TableExtract->new(headers => $headers);

  $te->parse($table);

  my @data;
  
  for my $row ($te->rows) {
    my %data = zip @$fields, @$row;
    s/%//g for values %data;
    push @data, \%data;
  }

  return @data;
}

sub _fetch_table {
  my $date = shift;
  my $stat_id = shift;
  my $headers = shift;
  my $fields = shift;

  my @data;

  my $vars = {
    type => "team-detail",
    league => "nfl",
    season_id => 9, # $year-2003+1, # seems to be the same all the time?
    cat_type => 4, #no idea
    view => "stats_v1",
    is_previous => 0,
    stat_id => $stat_id, # did they change it?
    date => $date->mdy,
  };

  my $res = $mech->post($baseurl, $vars);

  if ($res->is_success()) {
    @data = _parse_table($headers, $fields, $res->content);
  } else {
    die "Failed to fetch stats: ".$res->status_message();
  }

  return @data;
}

sub scrape_data {
  my $zone = shift;
  my $date = shift;

  my $year = $date->year;
  my $lastyear = $date->year - 1;

  my $headers = [qw(Rank Team), $year, "Last 3", "Last 1", qw(Home Away), $lastyear];
  my $fields = [qw(rank city current_season last_three last_one home away last_season)];

  my @data = _fetch_table($date, $zone, $headers, $fields);
  return @data;
};

1